@@ -246,7 +246,8 @@ escchr:
 			   (c == '}' && nodes[depth - 1].type != JSON_TYPE_OBJECT))
 				JSON_INVALID(); /* unbalanced nodes */
 
-			nodes[--depth].index++;
+			depth--;
+			nodes[depth].index++;
 			expect = EXPECT_END;
 			break;
 		case ',':
